<?php

namespace EventPortal\Concerns;

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Team\Models\Team;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\MorphToMany;
use Illuminate\Support\Facades\Auth;

trait HasTeams
{
    public function teamsAsOptions(): array
    {
        return $this->teams->map(static function (Team $team) {
            return Option::make($team->name)->value($team->id);
        })->toArray();
    }

    public function getTeamAttribute(): ?Team
    {
        return $this->teams->first();
    }

    public function teams(): MorphToMany
    {
        return $this->morphToMany(Team::class, 'teamable')->withTimeStamps();
    }

    public function belongsToTeam(Team $team): bool
    {
        return $this->teams->pluck('id')->contains($team->id);
    }

    public function belongsToSameTeamAs(Model $model): bool
    {
        return $this->teams->pluck('id')->intersect($model->teams->pluck('id'))->isNotEmpty();
    }

    public function doesNoBelongToSameTeamAs(Model $model): bool
    {
        return $this->teams->pluck('id')->intersect($model->teams->pluck('id'))->isEmpty();
    }

    public function scopeForAdminInTeam(Builder $query): Builder
    {
        $admin = Auth::user()->admin;
        if ($admin->hasRole('super-admin') || $admin->hasRole('compliance')) {
            return $query;
        }

        return $query->whereHas('teams', static function ($query) use ($admin): void {
            $query->whereIn('teams.id', $admin->teams->pluck('id'));
        });
    }
}
