<?php

namespace EventPortal\Domain\Event;

use EventPortal\Contracts\Event;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\EventDelegate\RegistrationStatus;
use EventPortal\Enums\InertiaMethod;

class BroadcastCallToAction
{
    private Event $event;

    private EventDelegate $eventDelegate;

    public static function make(): self
    {
        return new self();
    }

    public function forEventDelegate(EventDelegate $eventDelegate): self
    {
        $this->eventDelegate = $eventDelegate;
        $this->event = $eventDelegate->event;

        return $this;
    }

    public function get(): ?Button
    {
        if ($this->canBeDisplayed() === false) {
            return null;
        }

        return Button::make('Access the event')
            ->icon('chevron-right', 'right')
            ->method(InertiaMethod::VISIT())
            ->href($this->event->broadcast_URL);
    }

    /**
     * Broadcast link can be displayed if event is virtual and
     * link is set and event is published and delegate has registered
     */
    public function canBeDisplayed(): bool
    {
        return $this->event->is_virtual &&
            $this->event->broadcast_URL &&
            $this->event->status === 'published' &&
            $this->eventDelegate->statusIs(RegistrationStatus::registered());
    }
}
