<?php

namespace EventPortal\Imports;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\User\Models\User;
use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\ToCollection;
use Maatwebsite\Excel\Concerns\WithHeadingRow;

class AdminsImport implements ToCollection, WithHeadingRow
{
    public function collection(Collection $rows): void
    {
        foreach ($rows as $row) {
            $role = Role::findByName($row->get('role'));

            $user = User::create($this->getUserData($row));

            $admin = Admin::create($row->only(Admin::make()->getFillable())->toArray());

            $user->admin()->save($admin);

            $admin->assignRole($role);
        }
    }

    private function getUserData(Collection $row): array
    {
        $defaultPasswordData = [
            'password' => bcrypt(config('auth.default_password')),
            'password_created_at' => now(),
        ];

        return array_merge(
            $defaultPasswordData,
            $row->only(User::make()->getFillable())->toArray()
        );
    }
}
