<?php

namespace EventPortal\Tests\Unit\Event\Form\Models;

use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionOption;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class QuestionOptionTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function value_is_returned_as_boolean(): void
    {
        $question = factory(Question::class)->create(['type' => 'Checkboxes']);

        $questionOption = factory(QuestionOption::class)->create([
            'question_id' => $question->id,
            'name' => 'Question Title',
            'value' => '1',
        ]);

        $option = $questionOption->asOption();

        $this->assertTrue(is_bool($option->value));
    }

    /** @test */
    public function value_is_returned_true(): void
    {
        $question = factory(Question::class)->create(['type' => 'Checkboxes']);

        $questionOption = factory(QuestionOption::class)->create([
            'question_id' => $question->id,
            'name' => 'Question Title',
            'value' => '1',
        ]);

        $option = $questionOption->asOption();

        $this->assertTrue($option->value);
    }

    /** @test */
    public function value_is_returned_false(): void
    {
        $question = factory(Question::class)->create(['type' => 'Checkboxes']);

        $questionOption = factory(QuestionOption::class)->create([
            'question_id' => $question->id,
            'name' => 'Question Title',
            'value' => '0',
        ]);

        $option = $questionOption->asOption();

        $this->assertFalse($option->value);
    }
}
