<?php

namespace EventPortal\Tests\Unit\Event;

use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\Event\RegistrationCallToAction;
use EventPortal\Domain\EventDelegate\RegistrationStatus;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class RegistrationCallToActionTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function shows_button_to_start_registration()
    {
        $event = factory(Event::class)->state('snapshot')->create();
        $eventDelegate = factory(EventDelegate::class)->create(['event_id' => $event->id]);

        factory(Form::class)
            ->state('registration')
            ->create(['event_id' => $eventDelegate->event->id]);

        factory(Form::class)
            ->state('decline')
            ->create(['event_id' => $eventDelegate->event->id]);

        $callToAction = RegistrationCallToAction::make()->forEventDelegate($eventDelegate)->get();

        $this->assertEquals('Begin registration', $callToAction->label);
        $this->assertEquals([
            'event' => 'event-name',
            'form' => 'registration',
        ], $callToAction->routeParams);
    }

    /** @test **/
    public function shows_button_when_declined()
    {
        $event = factory(Event::class)->state('snapshot')->create();
        $eventDelegate = factory(EventDelegate::class)->create([
            'event_id' => $event->id,
            'status' => RegistrationStatus::declined(),
        ]);

        factory(Form::class)
            ->state('registration')
            ->create(['event_id' => $eventDelegate->event->id]);

        factory(Form::class)
            ->state('decline')
            ->create(['event_id' => $eventDelegate->event->id]);

        $callToAction = RegistrationCallToAction::make()->forEventDelegate($eventDelegate)->get();

        $this->assertEquals('View reason for declining', $callToAction->label);
        $this->assertEquals([
            'event' => 'event-name',
            'form' => 'decline',
        ], $callToAction->routeParams);
    }

    /** @test **/
    public function doesnt_show_button_when_cancelled(): void
    {
        $event = factory(Event::class)->state('snapshot')->create();
        $eventDelegate = factory(EventDelegate::class)->create([
            'event_id' => $event->id,
            'status' => RegistrationStatus::cancelled(),
        ]);

        factory(Form::class)
            ->state('registration')
            ->create(['event_id' => $eventDelegate->event->id]);

        factory(Form::class)
            ->state('decline')
            ->create(['event_id' => $eventDelegate->event->id]);

        $callToAction = RegistrationCallToAction::make()->forEventDelegate($eventDelegate)->get();

        $this->assertNull($callToAction);
    }
}
