<?php

namespace EventPortal\Tests\Unit\User\Handlers;

use EventPortal\Domain\Form\Payload;
use EventPortal\Domain\User\Handlers\CreateUser;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Pipeline\Pipeline;

class CreateUserTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_user()
    {
        $payload = Payload::make(['first_name' => 'Jeff'])->withModel(new User);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateUser])
            ->thenReturn();

        $this->assertDatabaseHas('users', [
            'first_name' => 'Jeff',
        ]);
    }

    /** @test **/
    public function hydrated_user_is_add_to_passable()
    {
        $model = new User;

        $payload = Payload::make(['first_name' => 'Jeff'])->withModel($model);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateUser])
            ->thenReturn();

        $this->assertNotSameModel($model, $payload->getModel());
        $this->assertEquals('Jeff', $payload->getModel()->first_name);
    }
}
